@@ -1,26 +1,23 @@
 # Copyright 2022 Amethyst Reese
 # Licensed under the MIT license
 import logging
-from dataclasses import dataclass, field
+from functools import lru_cache
 from pathlib import Path
-from typing import List, Optional, Sequence
+from typing import Optional, Sequence
 
 import tomlkit
 from trailrunner import project_root
 
+from .types import Formatter, Sorter, UfmtConfig
+
 LOG = logging.getLogger(__name__)
 
 
-@dataclass
-class UfmtConfig:
-    project_root: Optional[Path] = None
-    pyproject_path: Optional[Path] = None
-    excludes: List[str] = field(default_factory=list)
-
-
-def ufmt_config(path: Optional[Path] = None) -> UfmtConfig:
+@lru_cache
+def load_config(path: Optional[Path] = None, root: Optional[Path] = None) -> UfmtConfig:
     path = path or Path.cwd()
-    root = project_root(path)
+    if root is None:
+        root = project_root(path)
     config_path = root / "pyproject.toml"
     if config_path.is_file():
         pyproject = tomlkit.loads(config_path.read_text())
@@ -37,6 +34,9 @@ def ufmt_config(path: Optional[Path] = None) -> UfmtConfig:
         else:
             raise ValueError(f"{config_path}: excludes must be a list of strings")
 
+        formatter = Formatter(config.pop("formatter", UfmtConfig.formatter))
+        sorter = Sorter(config.pop("sorter", Sorter.usort))
+
         if config:
             LOG.warning("%s: unknown values ignored: %r", config_path, sorted(config))
 
@@ -44,6 +44,8 @@ def ufmt_config(path: Optional[Path] = None) -> UfmtConfig:
             project_root=root,
             pyproject_path=config_path,
             excludes=excludes,
+            formatter=formatter,
+            sorter=sorter,
         )
 
     return UfmtConfig()
