@@ -110,6 +110,7 @@ def ufmt_bytes(
         content = result.output
     elif ufmt_config.sorter == Sorter.ruff_api:
         ruff_isort_options = ruff_api.SortOptions(
+            # match µsort configuration
             first_party_modules=[
                 imp
                 for imp, category in usort_config.known.items()
@@ -120,9 +121,21 @@ def ufmt_bytes(
                 for imp, category in usort_config.known.items()
                 if category == CAT_STANDARD_LIBRARY
             ],
+            detect_same_package=usort_config.first_party_detection,
+            # match µsort behavior for now
+            case_sensitive=False,
+            combine_as_imports=True,
+            order_by_type=False,
         )
         content_str = ruff_api.isort_string(
-            path.as_posix(), content.decode(encoding), options=ruff_isort_options
+            path.as_posix(),
+            content.decode(encoding),
+            options=ruff_isort_options,
+            root=(
+                ufmt_config.project_root.as_posix()
+                if ufmt_config.project_root
+                else None
+            ),
         )
         content = content_str.encode(encoding)
     elif ufmt_config.sorter == Sorter.skip:
@@ -143,7 +156,7 @@ def ufmt_bytes(
                 mode=black_config,
             )
         except black.report.NothingChanged:
-            content = result.output
+            pass
     elif ufmt_config.formatter == Formatter.ruff_api:
         ruff_format_options = ruff_api.FormatOptions(
             target_version=str(
