@@ -4,6 +4,7 @@
 import os
 import platform
 from concurrent.futures import ThreadPoolExecutor
+from importlib.metadata import version
 from pathlib import Path
 from tempfile import TemporaryDirectory
 from unittest import skipIf, TestCase
@@ -12,6 +13,7 @@ from unittest.mock import call, Mock, patch
 import trailrunner
 from click.testing import CliRunner
 from libcst import ParserSyntaxError
+from packaging.version import Version
 
 from ufmt.cli import echo_results, main
 from ufmt.types import Result
@@ -22,7 +24,10 @@ from .core import CORRECTLY_FORMATTED_CODE, POORLY_FORMATTED_CODE
 @patch.object(trailrunner.core.Trailrunner, "DEFAULT_EXECUTOR", ThreadPoolExecutor)
 class CliTest(TestCase):
     def setUp(self) -> None:
-        self.runner = CliRunner(mix_stderr=False)
+        if Version(version("click")) >= Version("8.2.0"):
+            self.runner = CliRunner()
+        else:
+            self.runner = CliRunner(mix_stderr=False)
         self.cwd = os.getcwd()
         self.td = TemporaryDirectory()
         self.tdp = Path(self.td.name).resolve()
@@ -487,3 +492,26 @@ class CliTest(TestCase):
             self.assertIn("1 file formatted, 1 file already formatted", result.stderr)
             self.assertEqual(POORLY_FORMATTED_CODE, beta.read_text())
             self.assertEqual(CORRECTLY_FORMATTED_CODE, kappa.read_text())
+
+    @patch("ufmt.lsp.ufmt_lsp")  # dynamic import, patch at definition
+    def test_lsp(self, lsp_mock: Mock) -> None:
+        with self.subTest("default"):
+            lsp_mock.reset_mock()
+            self.runner.invoke(main, ["lsp"])
+
+            lsp_mock.assert_called_with(root=None)
+            lsp_mock.return_value.start_io.assert_called_with()
+
+        with self.subTest("tcp"):
+            lsp_mock.reset_mock()
+            self.runner.invoke(main, ["lsp", "--tcp", "--port", "4567"])
+
+            lsp_mock.assert_called_with(root=None)
+            lsp_mock.return_value.start_tcp.assert_called_with("localhost", 4567)
+
+        with self.subTest("ws"):
+            lsp_mock.reset_mock()
+            self.runner.invoke(main, ["lsp", "--ws", "--port", "8765"])
+
+            lsp_mock.assert_called_with(root=None)
+            lsp_mock.return_value.start_ws.assert_called_with("localhost", 8765)
